==> hoteldruid-mod-pt_2.1.2-2.zip: pt/modifica_app.php <==
<?php

switch ($messaggio) {

case "contiene prenotazione future, non si può cancellare":	$messaggio = "contém reservas futuras, não pode ser apagado"; break;
case "SI":  					$messaggio = "SIM"; break;
case "NO":  					$messaggio = "NÃO"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "La casa verrà cambiata da":  		$messaggio = "A casa será alterada de"; break;
case "a":  					$messaggio = "para"; break;
case "Il piano verrà cambiato da":  		$messaggio = "O andar será alterado de"; break;
case "Il massimo numero di occupanti verrà cambiato da":	$messaggio = "O número máximo de ocupação será alterado de"; break;
case "La priorità verrà cambiata da":  		$messaggio = "A prioridade será alterada de"; break;
case "Il commento verrà cambiato":  		$messaggio = "O comentário será alterado"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "Casa":  					$messaggio = "Casa"; break;
case "Cambia in":  				$messaggio = "Alterar para"; break;
case "Piano":  					$messaggio = "Andar"; break;
case "Capienza":  				$messaggio = "Capacidade"; break;
case "Priorità":  				$messaggio = "Prioridade"; break;
case "Commento":  				$messaggio = "Comentário"; break;
case "Persone":  				$messaggio = "Pessoas"; break;
case "anche se le loro caratteristiche non sono più compatibili":	$messaggio = "mesmo que as suas características já não sejam compatíveis"; break;
case "Nome":  		$messaggio = "Nome"; break;
case "esiste già":  				$messaggio = "já existe"; break;
case "non esiste più":  			$messaggio = "não existe mais"; break;
case "la nuova foto è stata aggiunta":  	$messaggio = "a nova foto foi adicionada"; break;
case "l'url della foto è sbagliata":  		$messaggio = "a URL da foto está errada"; break;
case "foto eliminata":  			$messaggio = "foto apagada"; break;
case "elimina":  				$messaggio = "apagar"; break;
case "url di una nuova foto":  			$messaggio = "url de uma nova foto"; break;
case "aggiungi":  				$messaggio = "adicionar"; break;
case "commento della foto":  			$messaggio = "Comentário à foto"; break;
case "aggiornato":  				$messaggio = "atualizado"; break;
case "aggiornata":  				$messaggio = "atualizada"; break;
case "modifica":  				$messaggio = "modificar"; break;
case "commento":  				$messaggio = "Comentário"; break;
case "Persona":  				$messaggio = "Pessoa"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-pt_3.0.8-1.zip: pt/modifica_app.php <==
<?php

switch ($messaggio) {

case "contiene prenotazione future, non si può cancellare":	$messaggio = "contém reservas futuras, não pode ser apagado"; break;
case "SI":  					$messaggio = "SIM"; break;
case "NO":  					$messaggio = "NÃO"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "La casa verrà cambiata da":  		$messaggio = "A casa será alterada de"; break;
case "a":  					$messaggio = "para"; break;
case "Il piano verrà cambiato da":  		$messaggio = "O andar será alterado de"; break;
case "Il massimo numero di occupanti verrà cambiato da":	$messaggio = "O número máximo de ocupação será alterado de"; break;
case "La priorità verrà cambiata da":  		$messaggio = "A prioridade será alterada de"; break;
case "Il commento verrà cambiato":  		$messaggio = "O comentário será alterado"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "Casa":  					$messaggio = "Casa"; break;
case "Cambia in":  				$messaggio = "Alterar para"; break;
case "Piano":  					$messaggio = "Andar"; break;
case "Capienza":  				$messaggio = "Capacidade"; break;
case "Priorità":  				$messaggio = "Prioridade"; break;
case "Commento":  				$messaggio = "Comentário"; break;
case "Persone":  				$messaggio = "Pessoas"; break;
case "anche se le loro caratteristiche non sono più compatibili":	$messaggio = "mesmo que as suas caraterísticas já não sejam compatíveis"; break;
case "Nome":  		$messaggio = "Nome"; break;
case "esiste già":  				$messaggio = "já existe"; break;
case "non esiste più":  			$messaggio = "não existe mais"; break;
case "la nuova foto è stata aggiunta":  	$messaggio = "a nova foto foi adicionada"; break;
case "l'url della foto è sbagliata":  		$messaggio = "a URL da foto está errada"; break;
case "foto eliminata":  			$messaggio = "foto apagada"; break;
case "elimina":  				$messaggio = "apagar"; break;
case "url di una nuova foto":  			$messaggio = "url de uma nova foto"; break;
case "aggiungi":  				$messaggio = "adicionar"; break;
case "commento della foto":  			$messaggio = "etiqueta da foto"; break;
case "aggiornato":  				$messaggio = "atualizado"; break;
case "aggiornata":  				$messaggio = "atualizada"; break;
case "modifica":  				$messaggio = "modificar"; break;
case "commento":  				$messaggio = "Comentário"; break;
case "Persona":  				$messaggio = "Pessoa"; break;
case "più bassa viene assegnata prima":  	$messaggio = "menor será atribuído primeiro"; break;
case "Rimane solo":  				$messaggio = "Resta apenas"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
